﻿
Public Class MainAccountForm

    Private m_objVaxUserAgent As cVaxSIPUserAgentExCOM
    Private m_bBtnAdvanceShow As Boolean = True

    Public Sub New(ByRef objVaxUserAgent As cVaxSIPUserAgentExCOM)

        InitializeComponent()
        m_objVaxUserAgent = objVaxUserAgent

    End Sub

    '//////////////////////////////////////////////////////////////////////////////////////////////////
    '//////////////////////////////////////////////////////////////////////////////////////////////////

    Private Sub AccountForm_Load(ByVal sender As Object, ByVal e As EventArgs) Handles MyBase.Load

        ComboServerType.Items.Add("UDP")
        ComboServerType.Items.Add("TCP")
        ComboServerType.Items.Add("TLS")

        ComboServerType.SelectedIndex = 0
        LoadAccountData()

    End Sub

    '//////////////////////////////////////////////////////////////////////////////////////////////////
    '//////////////////////////////////////////////////////////////////////////////////////////////////

    Private Sub BtnOnline_Click(ByVal sender As Object, ByVal e As EventArgs) Handles BtnOnline.Click

        If BtnOnline.Text = "Offline" Then

            m_objVaxUserAgent.UnInitialize()
            BtnOnline.Text = "Online"

            EditServerPort.Enabled = True
            Return

        End If

        If EditAuthLogin.Text = "" Then
            MessageBox.Show("Invalid auth Login.", "VaxVoIP SDK", MessageBoxButtons.OK, MessageBoxIcon.Exclamation)
            Return
        End If

        If EditServerAddr.Text = "" Then
            MessageBox.Show("Invalid SIP server domain or IP address.", "VaxVoIP SDK", MessageBoxButtons.OK, MessageBoxIcon.Exclamation)
            Return
        End If

        Dim nServerType As Integer = GetServerType()

        If Not m_objVaxUserAgent.Initialize(EditDisplayName.Text, EditUserName.Text, EditAuthLogin.Text, EditAuthPwd.Text, EditDomainRealm.Text, EditServerAddr.Text, Convert.ToInt32(EditServerPort.Text), nServerType, CheckRegisterToServerSIP.Checked, CheckCaptureSoundDevice.Checked) Then Return

        If CheckRegisterToServerSIP.Checked = False Then
            AddToStatusLog("Account is online.")
        End If

        BtnOnline.Text = "Offline"
        cStoreAccount.AddAccountInfo(EditDisplayName.Text, EditUserName.Text, EditAuthLogin.Text, EditAuthPwd.Text, EditDomainRealm.Text, EditServerAddr.Text, Convert.ToInt32(EditServerPort.Text), nServerType, CheckRegisterToServerSIP.Checked)

    End Sub

    '//////////////////////////////////////////////////////////////////////////////////////////////////
    '//////////////////////////////////////////////////////////////////////////////////////////////////

    Private Sub AddToStatusLog(ByVal sStatus As String)
        ListBoxStatusLog.Items.Add(sStatus)
        ListBoxStatusLog.TopIndex = ListBoxStatusLog.Items.Count - 1
    End Sub

    '//////////////////////////////////////////////////////////////////////////////////////////////////
    '//////////////////////////////////////////////////////////////////////////////////////////////////

    Public Sub OnNetworkReachability(ByVal bAvailable As Boolean)
        If bAvailable Then
            AddToStatusLog("Network is available")
        Else
            AddToStatusLog("Network is not available")
        End If
    End Sub

    '//////////////////////////////////////////////////////////////////////////////////////////////////
    '//////////////////////////////////////////////////////////////////////////////////////////////////

    Public Sub OnConnectingToRegister()
        AddToStatusLog("Connecting to register.")
    End Sub

    Public Sub OnTryingToRegister()
        AddToStatusLog("Trying to register.")
    End Sub

    Public Sub OnFailToRegister(ByVal nStatusCode As Integer, ByVal sReasonPhrase As String)
        AddToStatusLog("Failed: " & sReasonPhrase)
    End Sub

    Public Sub OnSuccessToRegister()
        AddToStatusLog("Success to register.")
    End Sub

    '//////////////////////////////////////////////////////////////////////////////////////////////////
    '//////////////////////////////////////////////////////////////////////////////////////////////////

    Public Sub OnConnectingToReRegister()
        AddToStatusLog("Connecting to re-register.")
    End Sub

    Public Sub OnTryingToReRegister()
        AddToStatusLog("Trying to Re-Register.")
    End Sub

    Public Sub OnFailToReRegister(ByVal nStatusCode As Integer, ByVal sReasonPhrase As String)
        AddToStatusLog("Failed: " & sReasonPhrase)
    End Sub

    Public Sub OnSuccessToReRegister()
        AddToStatusLog("Success to Re-Register.")
    End Sub

    '//////////////////////////////////////////////////////////////////////////////////////////////////
    '//////////////////////////////////////////////////////////////////////////////////////////////////

    Public Sub OnTryingToUnRegister()
        AddToStatusLog("Trying to Unregister.")
    End Sub

    Public Sub OnFailToUnRegister()
        AddToStatusLog("Fail to unregister.")
    End Sub

    Public Sub OnSuccessToUnRegister()
        AddToStatusLog("Unregistered successfully.")
    End Sub

    '//////////////////////////////////////////////////////////////////////////////////////////////////
    '//////////////////////////////////////////////////////////////////////////////////////////////////

    Private Sub BtnClearLog_Click(ByVal sender As Object, ByVal e As EventArgs) Handles BtnClearLog.Click
        ListBoxStatusLog.Items.Clear()
    End Sub

    '//////////////////////////////////////////////////////////////////////////////////////////////////
    '//////////////////////////////////////////////////////////////////////////////////////////////////

    Private Sub BtnAdvance_Click(ByVal sender As Object, ByVal e As EventArgs) Handles BtnAdvance.Click

        If m_bBtnAdvanceShow Then

            LabelDisplayName.Visible = True
            LabelUserName.Visible = True

            LabelDomainRealm.Visible = True
            EditDisplayName.Visible = True
            EditUserName.Visible = True

            EditDomainRealm.Visible = True
            BtnAdvance.Text = "Basic"
            m_bBtnAdvanceShow = False

            Return

        End If

        LabelDisplayName.Visible = False
        LabelUserName.Visible = False

        LabelDomainRealm.Visible = False
        EditDisplayName.Visible = False

        EditUserName.Visible = False
        EditDomainRealm.Visible = False

        BtnAdvance.Text = "Advance"
        m_bBtnAdvanceShow = True

    End Sub

    '//////////////////////////////////////////////////////////////////////////////////////////////////
    '//////////////////////////////////////////////////////////////////////////////////////////////////

    Private Sub BtnDemoAcc_Click(ByVal sender As Object, ByVal e As EventArgs) Handles BtnDemoAcc.Click

        Dim EpocTime As TimeSpan = DateTime.UtcNow - New DateTime(1970, 1, 1)
        Dim nEpocSeconds As Integer = CInt(EpocTime.TotalSeconds) Mod 9999999

        Dim sAccountDemo As String = nEpocSeconds.ToString()

        EditAuthLogin.Text = sAccountDemo
        EditAuthPwd.Text = sAccountDemo

        EditServerAddr.Text = "demo.vaxvoip.com"
        EditServerPort.Text = "8060"

        CheckRegisterToServerSIP.Checked = True
        ComboServerType.SelectedIndex = 0

        Dim sDemoMsg As String = ""
        sDemoMsg = vbLf & "Auth Login: " & sAccountDemo & vbLf
        sDemoMsg = sDemoMsg & "Auth Password: " & sAccountDemo & vbLf
        sDemoMsg = sDemoMsg & "Server Addr: " & EditServerAddr.Text & vbLf
        sDemoMsg = sDemoMsg & "Server Port: " & EditServerPort.Text & vbLf & " " & vbLf

        MessageBox.Show(sDemoMsg & "Demo accounts are only for account-to-account VoIP calls. Use demo accounts on different devices to dial/receive VoIP calls." & vbLf & vbLf & "Dial 000 for self testing." & vbLf & vbLf & "[Powered by VaxVoIP Server SDK]", "VaxVoIP SDK", MessageBoxButtons.OK, MessageBoxIcon.Information)

    End Sub

    Private Sub LoadAccountData()

        Dim sDisplayName As String = ""
        Dim sUserName As String = ""

        Dim sAuthLogin As String = ""
        Dim sAuthPwd As String = ""

        Dim sDomainRealm As String = ""

        Dim sServerAddr As String = ""
        Dim nServerPort As Integer = 5060

        Dim nServerType As Integer = cVaxSIPUserAgentCOM.VAX_ACCOUNT_TYPE_UDP
        Dim bRegisterSIP As Boolean = True

        cStoreAccount.GetAccountInfo(sDisplayName, sUserName, sAuthLogin, sAuthPwd, sDomainRealm, sServerAddr, nServerPort, nServerType, bRegisterSIP)

        EditDisplayName.Text = sDisplayName
        EditUserName.Text = sUserName

        EditAuthLogin.Text = sAuthLogin
        EditAuthPwd.Text = sAuthPwd

        EditDomainRealm.Text = sDomainRealm
        EditServerAddr.Text = sServerAddr
        EditServerPort.Text = Convert.ToString(nServerPort)

        CheckRegisterToServerSIP.Checked = bRegisterSIP
        UpdateServerType(nServerType)

    End Sub

    '//////////////////////////////////////////////////////////////////////////////////////////////////
    '//////////////////////////////////////////////////////////////////////////////////////////////////

    Public Sub OnVoiceMailMsg(ByVal bIsMsgWaiting As Boolean, ByVal nNewMsgCount As Integer, ByVal nOldMsgCount As Integer, ByVal nNewUrgentMsgCount As Integer, ByVal nOldUrgentMsgCount As Integer, ByVal sMsgAccount As String)

        If bIsMsgWaiting Then
            LabelIsMsgWaiting.Text = "Yes"
        Else
            LabelIsMsgWaiting.Text = "No"
        End If

        LabelNewMsgs.Text = Convert.ToString(nNewMsgCount)
        LabelOldMsgs.Text = Convert.ToString(nOldMsgCount)

    End Sub

    '//////////////////////////////////////////////////////////////////////////////////////////////////
    '//////////////////////////////////////////////////////////////////////////////////////////////////

    Private Sub UpdateServerType(ByVal nServerType As Integer)

        If nServerType = cVaxSIPUserAgentCOM.VAX_ACCOUNT_TYPE_UDP Then
            ComboServerType.SelectedIndex = 0
            LabelServerPort.Text = "Server Port UDP (Default: 5060)"
        ElseIf nServerType = cVaxSIPUserAgentCOM.VAX_ACCOUNT_TYPE_TCP Then
            ComboServerType.SelectedIndex = 1
            LabelServerPort.Text = "Server Port TCP (Default: 5060)"
        ElseIf nServerType = cVaxSIPUserAgentCOM.VAX_ACCOUNT_TYPE_TLS Then
            ComboServerType.SelectedIndex = 2
            LabelServerPort.Text = "Server Port TLS (Default: 5061)"
        End If

        If EditServerAddr.Text = "demo.vaxvoip.com" Then

            If nServerType = cVaxSIPUserAgentCOM.VAX_ACCOUNT_TYPE_TLS Then
                EditServerPort.Text = "8061"
            Else
                EditServerPort.Text = "8060"
            End If

        ElseIf EditServerPort.Text = "5060" OrElse EditServerPort.Text = "5061" OrElse EditServerPort.Text.Length = 0 Then

            If nServerType = cVaxSIPUserAgentCOM.VAX_ACCOUNT_TYPE_TLS Then
                EditServerPort.Text = "5061"
            Else
                EditServerPort.Text = "5060"
            End If

        End If

    End Sub

    '//////////////////////////////////////////////////////////////////////////////////////////////////
    '//////////////////////////////////////////////////////////////////////////////////////////////////

    Private Function GetServerType() As Integer

        If ComboServerType.SelectedIndex = 0 Then Return cVaxSIPUserAgentCOM.VAX_ACCOUNT_TYPE_UDP
        If ComboServerType.SelectedIndex = 1 Then Return cVaxSIPUserAgentCOM.VAX_ACCOUNT_TYPE_TCP
        If ComboServerType.SelectedIndex = 2 Then Return cVaxSIPUserAgentCOM.VAX_ACCOUNT_TYPE_TLS

        Return cVaxSIPUserAgentCOM.VAX_ACCOUNT_TYPE_UDP

    End Function

    Private Sub ComboServerType_SelectionChangeCommitted(ByVal sender As Object, ByVal e As EventArgs) Handles ComboServerType.SelectionChangeCommitted

        Dim nServerType As Integer = GetServerType()
        UpdateServerType(nServerType)

    End Sub


End Class

